==> galileo-1.0.0-py3-none-any.whl: galileo/resources/api/prompts/get_template_from_project_projects_project_id_templates_template_id_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.base_prompt_template_response import BasePromptTemplateResponse
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(project_id: str, template_id: str) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {"method": "get", "url": f"/projects/{project_id}/templates/{template_id}"}

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = BasePromptTemplateResponse.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, template_id: str, *, client: AuthenticatedClient
) -> Response[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    """Get Template From Project

     Get a prompt template from a project.

    Parameters
    ----------
    template_id : UUID4
        Prompt template ID.
    project_id : UUID4
        Prokect ID.
    db_read : Session, optional
        Session object to execute DB reads, by default Depends(get_db_read).

    Returns
    -------
    GetTemplateResponse
        Prompt template response.

    Args:
        project_id (str):
        template_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[BasePromptTemplateResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(project_id=project_id, template_id=template_id)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, template_id: str, *, client: AuthenticatedClient
) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    """Get Template From Project

     Get a prompt template from a project.

    Parameters
    ----------
    template_id : UUID4
        Prompt template ID.
    project_id : UUID4
        Prokect ID.
    db_read : Session, optional
        Session object to execute DB reads, by default Depends(get_db_read).

    Returns
    -------
    GetTemplateResponse
        Prompt template response.

    Args:
        project_id (str):
        template_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[BasePromptTemplateResponse, HTTPValidationError]
    """

    return sync_detailed(project_id=project_id, template_id=template_id, client=client).parsed


async def asyncio_detailed(
    project_id: str, template_id: str, *, client: AuthenticatedClient
) -> Response[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    """Get Template From Project

     Get a prompt template from a project.

    Parameters
    ----------
    template_id : UUID4
        Prompt template ID.
    project_id : UUID4
        Prokect ID.
    db_read : Session, optional
        Session object to execute DB reads, by default Depends(get_db_read).

    Returns
    -------
    GetTemplateResponse
        Prompt template response.

    Args:
        project_id (str):
        template_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[BasePromptTemplateResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(project_id=project_id, template_id=template_id)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, template_id: str, *, client: AuthenticatedClient
) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    """Get Template From Project

     Get a prompt template from a project.

    Parameters
    ----------
    template_id : UUID4
        Prompt template ID.
    project_id : UUID4
        Prokect ID.
    db_read : Session, optional
        Session object to execute DB reads, by default Depends(get_db_read).

    Returns
    -------
    GetTemplateResponse
        Prompt template response.

    Args:
        project_id (str):
        template_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[BasePromptTemplateResponse, HTTPValidationError]
    """

    return (await asyncio_detailed(project_id=project_id, template_id=template_id, client=client)).parsed

==> galileo-1.11.0-py3-none-any.whl: galileo/resources/api/prompts/get_template_from_project_projects_project_id_templates_template_id_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.base_prompt_template_response import BasePromptTemplateResponse
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(project_id: str, template_id: str) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {"method": "get", "url": f"/projects/{project_id}/templates/{template_id}"}

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = BasePromptTemplateResponse.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, template_id: str, *, client: AuthenticatedClient
) -> Response[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    """Get Template From Project

     Get a prompt template from a project.

    Parameters
    ----------
    template_id : UUID4
        Prompt template ID.
    project_id : UUID4
        Project ID.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context).

    Returns
    -------
    GetTemplateResponse
        Prompt template response.

    Args:
        project_id (str):
        template_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[BasePromptTemplateResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(project_id=project_id, template_id=template_id)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, template_id: str, *, client: AuthenticatedClient
) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    """Get Template From Project

     Get a prompt template from a project.

    Parameters
    ----------
    template_id : UUID4
        Prompt template ID.
    project_id : UUID4
        Project ID.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context).

    Returns
    -------
    GetTemplateResponse
        Prompt template response.

    Args:
        project_id (str):
        template_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[BasePromptTemplateResponse, HTTPValidationError]
    """

    return sync_detailed(project_id=project_id, template_id=template_id, client=client).parsed


async def asyncio_detailed(
    project_id: str, template_id: str, *, client: AuthenticatedClient
) -> Response[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    """Get Template From Project

     Get a prompt template from a project.

    Parameters
    ----------
    template_id : UUID4
        Prompt template ID.
    project_id : UUID4
        Project ID.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context).

    Returns
    -------
    GetTemplateResponse
        Prompt template response.

    Args:
        project_id (str):
        template_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[BasePromptTemplateResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(project_id=project_id, template_id=template_id)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, template_id: str, *, client: AuthenticatedClient
) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    """Get Template From Project

     Get a prompt template from a project.

    Parameters
    ----------
    template_id : UUID4
        Prompt template ID.
    project_id : UUID4
        Project ID.
    ctx : Context, optional
        User context with database session, by default Depends(get_user_context).

    Returns
    -------
    GetTemplateResponse
        Prompt template response.

    Args:
        project_id (str):
        template_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[BasePromptTemplateResponse, HTTPValidationError]
    """

    return (await asyncio_detailed(project_id=project_id, template_id=template_id, client=client)).parsed
